// Program 11-6

import java.util.Scanner;
import java.io.*;

public class Program11_6
{
   public static void main(String[] args) throws IOException
   {  
      // Declare a variable to hold the
      // user's menu selection.
      int menuSelection;
      
      do
      {     
         // Display the menu and get the
         // user's selection.
         menuSelection = displayMenu();
   
         // Perform the selected operation.
         switch(menuSelection)
         {
            case 1:
               addRecord();
               break;
               
            case 2:
               searchRecord();
               break;
               
            case 3:
               modifyRecord();
               break;

            case 4:
               deleteRecord();
               break;

            case 5:
               displayRecords();
               break;
         }
      } while (menuSelection != 6);
   }
   
   // The displayMenu method displays the menu and
   // prompts the user for a selection. The selected
   // value is validated and returned from the method.
   public static int displayMenu()
   {
      // Declare a variable to hold the
      // user's menu selection.
      int selection;

      // Create a Scanner object for keyboard input.
      Scanner keyboard = new Scanner(System.in);
      
      // Display the menu.
      System.out.println("         Inventory Menu");
      System.out.println("1. Add a record.");
      System.out.println("2. Search for a record.");
      System.out.println("3. Modify a record.");
      System.out.println("4. Delete a record.");
      System.out.println("5. Display all records.");
      System.out.println("6. End the program.");
      System.out.println();
      
      // Prompt the user for a selection
      System.out.print("Enter your selection: ");
      selection = keyboard.nextInt();
      
      // Validate the menu selection.
      while (selection < 1 || selection > 6)
      {
         System.out.println("That is an invalid selection.");
         System.out.print("Enter 1, 2, 3, 4, 5, or 6: ");
         selection = keyboard.nextInt();
      }
      
      // Return the menu selection.
      return selection;
   }
   
   // The addRecord method lets the user add a record
   // to the inventory file.
   public static void addRecord() throws IOException
   {
      // Variables for the fields.
      String description;
      double quantity;

      // A variable to control the loop.
      String another = "Y";
      
      // Create a Scanner object for keyboard input.
      Scanner keyboard = new Scanner(System.in);
      
      // Open the file in append mode.
      PrintWriter coffeeFile = 
         new PrintWriter(new FileWriter("coffee.dat", true));
      
      while (another.equalsIgnoreCase("Y"))
      {
         // Get the description.
         System.out.print("Enter the description: ");
         description = keyboard.nextLine();
         
         // Get the quantity on hand.
         System.out.print("Enter the quantity on hand " +
                          "(in pounds): ");
         quantity = keyboard.nextDouble();
         // Read the remaining newline character...
         keyboard.nextLine();
         
         // Append the record to the file.
         coffeeFile.println(description);
         coffeeFile.println(quantity);
         
         // Determine whether the user wants to
         // enter another record.
         System.out.println("Do you want to enter another record?");
         System.out.print("Enter y for yes or anything else for no: ");
         another = keyboard.nextLine();
         
         // Display a blank line.
         System.out.println();
      }

      // Close the file.
      coffeeFile.close();
      System.out.println("Data appended to coffee.dat.");
   }

   // The searchRecord method allows the user to
   // search for a record in the inventory file.
   public static void searchRecord() throws IOException
   {
      // Variables for the fields.
      String description;
      double quantity;
      
      // A variable to hold the search value.
      String searchValue;
      
      // A flag to indicate whether the value was found.
      boolean found = false;
      
      // Create a Scanner object for keyboard input.
      Scanner keyboard = new Scanner(System.in);
      
      // Get the value to search for.
      System.out.print("Enter a value to search for: ");
      searchValue = keyboard.nextLine();
      
      // Open a file named employees.dat.
      Scanner coffeeFile = new Scanner(new File("coffee.dat"));
      
      // Display the records in the file.
      while (coffeeFile.hasNext())
      {
         // Read a record from the file.
         // First, read the description.
         description = coffeeFile.nextLine();
         
         // Next read the quantity.
         quantity = coffeeFile.nextDouble();
         // Read the newline that was left by nextDouble...
         coffeeFile.nextLine();
         
         // If the record contains the search value
         // then display it.
         if (description.indexOf(searchValue) != -1)
         {
            System.out.println("Description: " + description);
            System.out.println("Quantity on hand: " + quantity);
            
            // Set the found flag to true.
            found = true;
         }
      }

      // If the value was not found in the file then
      // display a message indicating so.
      if (!found)
         System.out.println(searchValue + " was not found.");
         
      // Close the file.
      coffeeFile.close();
   }  

   // The modifyRecord method allows the user to modify
   // an existing record in the inventory file.
   public static void modifyRecord() throws IOException
   {
      // Variables for the fields.
      String description;
      double quantity;
      
      // A variable to hold the new quantity.
      double newQuantity;
      
      // A variable to hold the search value.
      String searchValue;
      
      // A flag to indicate whether the value was found.
      boolean found = false;
      
      // Create a Scanner object for keyboard input.
      Scanner keyboard = new Scanner(System.in);
      
      // Open the employees.dat file.
      Scanner coffeeFile = new Scanner(new File("coffee.dat"));
      
      // Open a temporary file to copy the original file to.
      PrintWriter tempFile = new PrintWriter(new File("temp.dat"));
      
      // Get the value to search for.
      System.out.print("Enter a value to search for: ");
      searchValue = keyboard.nextLine();
      
      // Get the new quantity.
      System.out.print("Enter the new quantity: ");
      newQuantity = keyboard.nextDouble();
      
      // Display the records in the file.
      while (coffeeFile.hasNext())
      {
         // Read a record from the file.
         // First, read the description.
         description = coffeeFile.nextLine();
         
         // Next read the quantity.
         quantity = coffeeFile.nextDouble();
         // Read the newline that was left by nextDouble...
         coffeeFile.nextLine();
         
         // Write either this record to the temporary file or
         // the new record if this is the one to be changed.
         if (description.equalsIgnoreCase(searchValue))
         {
            tempFile.println(description);
            tempFile.println(newQuantity);
            found = true;
         }
         else
         {
            tempFile.println(description);
            tempFile.println(quantity);
         }
      }

      // Close the original file.
      coffeeFile.close();
      
      // Close the temporary file.
      tempFile.close();
      
      // Open the original file for output, thus
      // erasing its contents.
      PrintWriter coffeeFile2 = new PrintWriter("coffee.dat");
      
      // Open the temporary file for input.
      Scanner tempFile2 = new Scanner(new File("temp.dat"));
      
      // Copy each record from the temp file to
      // the original file.
      while(tempFile2.hasNext())
      {
         // Read a record from the temp file.
         description = tempFile2.nextLine();
         quantity = tempFile2.nextDouble();
         tempFile2.nextLine();
         
         // Write the reocrd to the original file.
         coffeeFile2.println(description);
         coffeeFile2.println(quantity);
      }
      
      // Close the original file.
      coffeeFile2.close();
      
      // Close the temporary file.
      tempFile2.close();      

      // If the value was not found in the file then
      // display a message indicating so.
      if (!found)
         System.out.println(searchValue + " was not found.");
   }
   
   // The deleteRecord method allows the user to delete
   // a record from the inventory file.
   public static void deleteRecord() throws IOException
   {
      // Variables for the fields.
      String description;
      double quantity;
      
      // A variable to hold the search value.
      String searchValue;
      
      // Create a Scanner object for keyboard input.
      Scanner keyboard = new Scanner(System.in);
      
      // Open the employees.dat file.
      Scanner coffeeFile = new Scanner(new File("coffee.dat"));
      
      // Open a temporary file to copy the original file to.
      PrintWriter tempFile = new PrintWriter(new File("temp.dat"));
      
      // Get the value to search for.
      System.out.print("Enter the coffee you want to delete: ");
      searchValue = keyboard.nextLine();
      
      // Display the records in the file.
      while (coffeeFile.hasNext())
      {
         // Read a record from the file.
         // First, read the description.
         description = coffeeFile.nextLine();
         
         // Next read the quantity.
         quantity = coffeeFile.nextDouble();
         // Read the newline that was left by nextDouble...
         coffeeFile.nextLine();
         
         // If this is not the record to delete then
         // write it to the temp file.
         if (!description.equalsIgnoreCase(searchValue))
         {
            tempFile.println(description);
            tempFile.println(quantity);
         }
      }

      // Close the original file.
      coffeeFile.close();
      
      // Close the temporary file.
      tempFile.close();
      
      // Open the original file for output, thus
      // erasing its contents.
      PrintWriter coffeeFile2 = new PrintWriter("coffee.dat");
      
      // Open the temporary file for input.
      Scanner tempFile2 = new Scanner(new File("temp.dat"));
      
      // Copy each record from the temp file to
      // the original file.
      while(tempFile2.hasNext())
      {
         // Read a record from the temp file.
         description = tempFile2.nextLine();
         quantity = tempFile2.nextDouble();
         tempFile2.nextLine();
         
         // Write the reocrd to the original file.
         coffeeFile2.println(description);
         coffeeFile2.println(quantity);
      }
      
      // Close the original file.
      coffeeFile2.close();
      
      // Close the temporary file.
      tempFile2.close();      

      System.out.println("The file was updated.");
   }

   // The displayRecords method displays all
   // of the records in the inventory file.
   public static void displayRecords() throws IOException
   {
      // Variables for the fields.
      String description;
      double quantity;
      
      // Open a file named employees.dat.
      Scanner coffeeFile = new Scanner(new File("coffee.dat"));
      
      // Display the records in the file.
      while (coffeeFile.hasNext())
      {
         // Read a record from the file.
         // First, read the description.
         description = coffeeFile.nextLine();
         
         // Next read the quantity.
         quantity = coffeeFile.nextDouble();
         // Read the newline that was left by nextDouble...
         coffeeFile.nextLine();
         
         // Display the record.
         System.out.println("Description: " + description);
         System.out.println("Quantity: " + quantity);
      }

      // Close the file.
      coffeeFile.close();
   }
}